import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="timed-functions",  # Replace with your own username
    version="0.1.0",
    description="Decorator to print how long each decorated function takes to complete.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/carloshenrique153/timed-functions",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3"
    ],
    python_requires='>=3.8',
)



import time


def timing(f):
    def print_duration(*args, **kwargs):
        start = time.time()

        ret = f(*args, **kwargs)

        millis = (time.time() - start) * 1000.0
        print("@timing - '{:s}' took {:.3f} ms".format(f.__name__, millis))
        return ret

    return print_duration
